﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;


//to use the namespace RohdeSchwarz.RsSpecAn, add the reference to the last RohdeSchwarz.RsSpecAn.Fx40 assembly from:
//"c:\Program Files\Rohde-Schwarz\RsSpecAn\Bin\RohdeSchwarz.RsSpecAn.Fx40.dll" - 64-bit target application
//"c:\Program Files (x86)\Rohde-Schwarz\RsSpecAn\Bin\RohdeSchwarz.RsSpecAn.Fx40.dll" - 32-bit target application
using RohdeSchwarz.RsSpecAn;

namespace Hardcopy
{
    class Program
    {
        static void Main(string[] args)
        {
            //Before running, change the resource name to fit your device:
            //- For LAN interface use TCPIP::<IP_Address>::HISLIP e.g. TCPIP::10.85.0.22::HISLIP
            //- For GPIB interface use the GPIB::<Address>::INSTR e.g.GPIB::28::INSTR
            string resource_name = "TCPIP::10.85.0.22::HISLIP";
            bool id_query = true;
            bool reset_device = true;
            RsSpecAn driver;

            string instrumentFileLocation = "c:\\temp\\my_RsSpecAn_IVI.NET_FSx_screenshot.png";
            string pcFileLocation = "c:\\temp\\my_RsSpecAn_IVI.NET_PC_screenshot.png";

            Console.Write("Initializing instrument with resource name '{0}' ... ", resource_name);
            try
            {
                driver = new RsSpecAn(resource_name, id_query, reset_device);
                Console.WriteLine("OK\n");
                Console.Write("Instrument *IDN query response: ");
                Console.WriteLine(driver.UtilityFunctions.QueryString("*IDN?"));
            }
            catch (Ivi.Driver.IOException e)
            {
                Console.WriteLine("ERROR!");
                Console.WriteLine("Cannot initialize the driver session.");
                Console.WriteLine(e.Message);
                Console.WriteLine("Press any key to finish...");
                Console.ReadKey();
                return;
            }

            try
            {
                Console.Write("Enabling remote display update ... ");
                driver.Display.Update = true;
                Console.WriteLine("OK\n");

                Console.Write("Configuring hardcopy device generate a PNG file... ");
                driver.HardCopy.Destination["DE1"].DeviceDestination = HcopyDevice.File;
                driver.HardCopy.Destination["DE1"].LanguageFormat = HcopyDeviceLang.PNG;
                driver.HardCopy.Destination["DE1"].DeviceOrientation = HcopyDeviceOrient.Landscape;
                driver.HardCopy.CommentScreen = "RsSpecAn IVI.NET Hardcopy Test";
                
                Console.WriteLine("OK\n");

                Console.Write("Configuring file name. This is where the hardcopy shall be stored on the instrument file: %{0} ... ", instrumentFileLocation);
                driver.HardCopy.FileName = instrumentFileLocation;
                Console.WriteLine("Ok\n");

                Console.Write("Executing hardcopy print... ");
                driver.HardCopy.Destination["DE1"].Print();
                Console.WriteLine("OK\n");

                Console.Write("Transfering file '{0}' from the instrument to the PC file '{1}' ... ", instrumentFileLocation, pcFileLocation);
                driver.UtilityFunctions.ReadToFileFromInstrument(instrumentFileLocation, pcFileLocation);
                Console.WriteLine("OK\n");
            }
            //driver IO error
            catch (Ivi.Driver.IOException e)
            {
                Console.WriteLine("Driver error occured:");
                Console.WriteLine(e.Message);
            }

            //driver function is not supported by this sensor
            catch (Ivi.Driver.OperationNotSupportedException e)
            {
                Console.WriteLine("Instrument doesn't support the function:");
                Console.WriteLine(e.Message);
            }

            //when a task takes longer than the defined OPC timeout
            catch (Ivi.Driver.MaxTimeExceededException e)
            {
                Console.WriteLine("Operation took longer than the defined OPC timeout ({0} ms):", driver.UtilityFunctions.OPCTimeout);
                Console.WriteLine(e.Message);
            }

            //if the instrument returns an error in the error queue
            catch (Ivi.Driver.InstrumentStatusException e)
            {
                Console.WriteLine("Instrument system error occured:");
                Console.WriteLine(e.Message);

            }

            //if the instrument returns an error in the error queue
            catch (Ivi.Driver.SelectorNameException e)
            {
                Console.WriteLine("Invalid selector name used:");
                Console.WriteLine(e.Message);

            }

            finally
            {
                Console.WriteLine("\n\nPress any key to finish.\nThe screenshot file '{0}' on the instrument will be deleted ...", instrumentFileLocation);
                Console.ReadKey();

                try
                {
                    //if the file doesn't exit, Ivi.Driver.InstrumentStatusException is thrown
                    driver.FileSpecAn.Manager.Delete(instrumentFileLocation);
                }
                catch(Ivi.Driver.InstrumentStatusException)
                {
                    ;
                }
            }
        }
    }
}